# Basic Math Library

This package provides users with a basic interface for evaluating functions.

## Usage

```py
import mathSym


mathSym.create_eq("<Your Equation Here>")
```

The 'equation' function will prvide an object with the following methods for use:

* Print
* Evaluate
  
Print will print out how the program interpreted the equation given.

Evaluate takes in a parameter 'x', to be used as the variable placeholder.

## More info

[Github](https://github.com/adasneves127/mathSym)
